# typhooninfo

<h1>
  How to install typhooninfo on Linux, MacOS, or WSL on Windows
</h1>
$ pip install typhooninfo

<h1>
  How to run typhooninfo 
</h1>
$ typhooninfo year <br>
year between 2001 and the present <br>
ex. $ typhooninfo 2019
<img src = 'https://github.com/yugo-Ishihara/typhooninfo/blob/main/result.png'>
